@@ -10,6 +10,7 @@ API Reference
 -------------
 
 .. autofunction:: parse
+.. autofunction:: parse_string
 .. autoclass:: Configuration
 
 
@@ -46,20 +47,9 @@ import pathlib
 import re
 import sys
 from collections import OrderedDict
+from collections.abc import Iterable, Iterator
 from datetime import timedelta
-from typing import (
-    IO,
-    Any,
-    Dict,
-    Iterable,
-    Iterator,
-    List,
-    NoReturn,
-    Optional,
-    Set,
-    Tuple,
-    Union,
-)
+from typing import IO, Any, NoReturn, Optional, Union
 
 from ._helpers import JSONDateEncoder, open_or_return
 
@@ -114,13 +104,24 @@ def parse(fo: Union[str, pathlib.Path, IO[str]]) -> "Configuration":
     return conf
 
 
+def parse_string(string: str, source: Optional[str] = None) -> "Configuration":
+    """Parse configuration data from a string.
+
+    Optional *source* argument can be used to set the context path of built
+    Configuration.
+    """
+    conf = Configuration(source)
+    conf.parse_string(string)
+    return conf
+
+
 def parse_include(
     conf: "Configuration",
     path: pathlib.Path,
     include_type: IncludeType,
     from_path: pathlib.Path,
     *,
-    _processed: Optional[Set[pathlib.Path]] = None,
+    _processed: Optional[set[pathlib.Path]] = None,
 ) -> Iterator[None]:
     """Parse on include directive with 'path' value of type 'include_type' into
     'conf' object.
@@ -215,9 +216,10 @@ def parse_value(raw: str) -> Value:
         # unquote value and unescape quotes
         raw = raw[1:-1].replace("''", "'").replace(r"\'", "'")
 
-    if raw.startswith("0"):
+    if raw.startswith("0") and raw != "0":
         try:
-            return int(raw, base=8)
+            int(raw, base=8)
+            return raw
         except ValueError:
             pass
 
@@ -295,7 +297,7 @@ class Entry:
         )
 
     def __repr__(self) -> str:
-        return "<%s %s=%s%s>" % (
+        return "<{} {}={}{}>".format(
             self.__class__.__name__,
             self.name,
             self.value,
@@ -339,7 +341,7 @@ class Entry:
                         continue
                     value = seconds // mod
                     break
-            value = "'%s%s'" % (value, unit)
+            value = "'{}{}'".format(value, unit)
         else:
             value = str(value)
         return value
@@ -353,7 +355,7 @@ class Entry:
         return line
 
 
-class EntriesProxy(Dict[str, Entry]):
+class EntriesProxy(dict[str, Entry]):
     """Proxy object used during Configuration edition.
 
     >>> p = EntriesProxy(port=Entry('port', '5432'),
@@ -460,8 +462,8 @@ class Configuration:
     .. automethod:: save
 
     """  # noqa
-    lines: List[str]
-    entries: Dict[str, Entry]
+    lines: list[str]
+    entries: dict[str, Entry]
     path: Optional[str]
 
     _parameter_re = re.compile(
@@ -484,7 +486,7 @@ class Configuration:
             )
         )
 
-    def parse(self, fo: Iterable[str]) -> Iterator[Tuple[pathlib.Path, IncludeType]]:
+    def parse(self, fo: Iterable[str]) -> Iterator[tuple[pathlib.Path, IncludeType]]:
         for raw_line in fo:
             self.lines.append(raw_line)
             line = raw_line.strip()
@@ -492,7 +494,12 @@ class Configuration:
                 continue
             commented = False
             if line.startswith("#"):
-                # Try to parse the uncommented line.
+                # Try to parse the commented line as a commented parameter,
+                # but only if in the form of 'name = value' since we cannot
+                # discriminate a commented sentence (with whitespaces) from a
+                # commented parameter in the form of 'name value'.
+                if "=" not in line:
+                    continue
                 line = line.lstrip("#").lstrip()
                 m = self._parameter_re.match(line)
                 if not m:
@@ -532,6 +539,13 @@ class Configuration:
                     **kwargs,
                 )
 
+    def parse_string(self, string: str) -> None:
+        try:
+            next(self.parse(string.splitlines(keepends=True)))
+        except StopIteration:
+            return
+        raise ValueError("cannot process include directives from a string value")
+
     def __add__(self, other: Any) -> "Configuration":
         cls = self.__class__
         if not isinstance(other, cls):
@@ -607,8 +621,8 @@ class Configuration:
     def __iter__(self) -> Iterator[Entry]:
         return iter(self.entries.values())
 
-    def as_dict(self) -> Dict[str, Value]:
-        return dict([(k, v.value) for k, v in self.entries.items() if not v.commented])
+    def as_dict(self) -> dict[str, Value]:
+        return {k: v.value for k, v in self.entries.items() if not v.commented}
 
     @contextlib.contextmanager
     def edit(self) -> Iterator[EntriesProxy]:
@@ -681,7 +695,7 @@ class Configuration:
                 fo.write(line)
 
 
-def _main(argv: List[str]) -> int:  # pragma: nocover
+def _main(argv: list[str]) -> int:  # pragma: nocover
     try:
         conf = parse(argv[0] if argv else sys.stdin)
         print(json.dumps(conf.as_dict(), cls=JSONDateEncoder, indent=2))
