@@ -71,9 +71,10 @@ path as first argument, read it, validate it, sort it and output it in stdout.
 import os
 import sys
 import warnings
+from collections.abc import Iterable, Iterator
 from contextlib import contextmanager
 from pathlib import Path
-from typing import IO, Callable, Iterable, Iterator, List, Optional, Tuple, Union
+from typing import IO, Callable, Optional, Union
 
 from ._helpers import open_or_stdin
 from .errors import ParseError
@@ -122,7 +123,7 @@ class PassComment(str):
     """
 
     def __repr__(self) -> str:
-        return "<%s %.32s>" % (self.__class__.__name__, self)
+        return "<{} {:.32}>".format(self.__class__.__name__, self)
 
     def __lt__(self, other: str) -> bool:
         if isinstance(other, PassEntry):
@@ -198,9 +199,10 @@ class PassEntry:
         fields = list(escapedsplit(line.strip(), ":"))
         if len(fields) != 5:
             raise ValueError("Invalid line.")
-        if fields[1] != "*":
-            fields[1] = int(fields[1])  # type: ignore[call-overload]
-        return cls(*fields)
+        hostname, port, database, username, password = fields
+        return cls(
+            hostname, int(port) if port != "*" else port, database, username, password
+        )
 
     def __init__(
         self,
@@ -240,7 +242,7 @@ class PassEntry:
         return NotImplemented
 
     def __repr__(self) -> str:
-        return "<%s %s@%s:%s/%s>" % (
+        return "<{} {}@{}:{}/{}>".format(
             self.__class__.__name__,
             self.username,
             self.hostname,
@@ -253,7 +255,7 @@ class PassEntry:
             [str(x).replace("\\", r"\\").replace(":", r"\:") for x in self.as_tuple()]
         )
 
-    def as_tuple(self) -> Tuple[str, str, str, str, str]:
+    def as_tuple(self) -> tuple[str, str, str, str, str]:
         return (
             self.hostname,
             str(self.port),
@@ -262,7 +264,7 @@ class PassEntry:
             self.password,
         )
 
-    def sort_key(self) -> Tuple[int, str, Union[int, str], str, str]:
+    def sort_key(self) -> tuple[int, str, Union[int, str], str, str]:
         tpl = self.as_tuple()[:-1]
         # Compute precision from * occurences.
         precision = len([x for x in tpl if x == "*"])
@@ -310,11 +312,14 @@ class PassFile:
 
     """
 
-    lines: List[Union[PassComment, PassEntry]]
+    lines: list[Union[PassComment, PassEntry]]
     path: Optional[str] = None
 
     def __init__(
-        self, entries: Optional[List[Union[PassComment, PassEntry]]] = None
+        self,
+        entries: Optional[list[Union[PassComment, PassEntry]]] = None,
+        *,
+        path: Optional[str] = None,
     ) -> None:
         """PassFile constructor.
 
@@ -323,7 +328,7 @@ class PassFile:
         if entries and not isinstance(entries, list):
             raise ValueError("%s should be a list" % entries)
         self.lines = entries or []
-        self.path = None
+        self.path = path
 
     def __iter__(self) -> Iterator[PassEntry]:
         """Iterate entries
@@ -403,6 +408,11 @@ class PassFile:
         if fo:
             _write(fo, self.lines)
         elif self.path:
+            fpath = Path(self.path)
+            if not fpath.exists():
+                if not self.lines:
+                    return
+                fpath.touch(mode=0o600)
             with open(self.path, "w") as fo:
                 _write(fo, self.lines)
         else:
@@ -442,13 +452,14 @@ class PassFile:
         if filter is not None:
             # Silently handle the case when line is a PassComment
             def filter_(line: Union[PassComment, PassEntry]) -> bool:
+                assert filter is not None
                 if isinstance(line, PassComment):
                     try:
-                        return filter(line.entry)  # type: ignore[misc]
+                        return filter(line.entry)
                     except ValueError:
                         return False
                 else:
-                    return filter(line)  # type: ignore[misc]
+                    return filter(line)
 
         else:
 
@@ -466,7 +477,7 @@ def parse(file: Union[Path, str, IO[str]]) -> PassFile:
     :rtype: :class:`PassFile`
     """
     if isinstance(file, (Path, str)):
-        with open(file) as fo:
+        with open(os.path.expanduser(file)) as fo:
             pgpass = parse(fo)
             pgpass.path = str(file)
     else:
@@ -482,10 +493,11 @@ def edit(fpath: Union[Path, str]) -> Iterator[PassFile]:
     If the file does not exists, it is created with 600 permissions.
     Upon exit of the context manager, the file is saved, if no error occurred.
     """
-    fpath = Path(fpath)
-    if not fpath.exists():
-        fpath.touch(mode=0o600)
-    passfile = parse(fpath)
+    fpath = Path(fpath).expanduser()
+    if fpath.exists():
+        passfile = parse(fpath)
+    else:
+        passfile = PassFile(path=str(fpath))
     yield passfile
     passfile.save()
 
